@@ -19,6 +19,7 @@ import time
 import datetime
 from .utils import download_geo, Gaussian, MobilityTransform, remove_outliers
 from collections import defaultdict, Counter
+from sklearn.metrics import silhouette_score
 EARTH_RADIUS = 6371.009
 
 
@@ -340,6 +341,10 @@ class Mobility(object):
                                     month=_.tm_mon,
                                     day=_.tm_mday) - delta
             return day
+        if isinstance(day, dict):
+            return datetime.datetime(year=day["year"],
+                                     month=day["month"],
+                                     day=day["day"])
         if hasattr(day, "year") and hasattr(day, "month") and hasattr(day, "day"):
             return datetime.datetime(year=day.year,
                                      month=day.month,
@@ -436,12 +441,15 @@ class Mobility(object):
         """
         return self.overall(level=level)
 
-    def overall(self, level=None):
+    def overall(self, level=None, pandas=False):
         """
         Overall mobility, this counts for outward, inward and inside travels
         in the region of interest (i.e., level).
 
         :param level: Aggregation function
+        :type level: function
+        :param pandas: Mobility as a DataFrame
+        :type pandas: bool
         """
 
         if level is None:
@@ -459,13 +467,20 @@ class Mobility(object):
                     if dest_code is not None and dest_code != ori_code:
                         matriz.update({dest_code: cnt})
             output.append(matriz)
-        return self.fill_with_zero(output)
+        output = self.fill_with_zero(output)
+        if pandas is False:
+            return output
+        else:
+            import pandas as pd
+            return pd.DataFrame(output, index=self.dates)
 
-    def inside_mobility(self, level=None):
+    def inside_mobility(self, level=None, pandas=False):
         """
         Mobility inside the region defined by level
 
         :param level: Aggregation function
+        :param pandas: Mobility as a DataFrame
+        :type pandas: bool        
         """
 
         if level is None:
@@ -483,7 +498,12 @@ class Mobility(object):
                     if dest_code == ori_code:
                         matriz.update({ori_code: cnt})
             output.append(matriz)
-        return self.fill_with_zero(output)
+        output = self.fill_with_zero(output)
+        if pandas is False:
+            return output
+        else:
+            import pandas as pd
+            return pd.DataFrame(output, index=self.dates)
 
     def inside_outward(self, level):
         """
@@ -675,6 +695,88 @@ class Mobility(object):
 
         return {k: func[k].transform(v) for k, v in data.items() if k in func}
 
+
+class MobilityWeekday(Mobility):
+    """Represent mobility as the percentage of change
+    using the weekday information as the baseline
+    
+    :param baseline: Number of days to create the baseline
+    :type baseline: int
+    """
+
+    def __init__(self, day=None, baseline=91, **kwargs):
+        super(MobilityWeekday, self).__init__(day=day, **kwargs)
+        self._baseline = Mobility(day=self.dates[0], window=baseline)
+
+    @property
+    def baseline(self):
+        """Baseline used to compute the percentage"""
+
+        return self._baseline
+
+    def overall(self, level=None, pandas=False):
+        output = super(MobilityWeekday, self).overall(level=level)
+        _ = self.baseline.overall(level=level)
+        transform = self.baseline.weekday_percentage(_)
+        output = self.transform(output, transform)
+        if pandas:
+            import pandas as pd
+            return pd.DataFrame(output, index=self.dates)
+        return output
+
+    def inside_mobility(self, level=None, pandas=False):
+        output = super(MobilityWeekday, self).inside_mobility(level=level)
+        _ = self.baseline.inside_mobility(level=level)
+        transform = self.baseline.weekday_percentage(_)
+        output = self.transform(output, transform)
+        if pandas:
+            import pandas as pd
+            return pd.DataFrame(output, index=self.dates)
+        return output
+
+
+class MobilityCluster(Mobility):
+    """Represent mobility as the percentage of change
+    using KMeans to create the baseline information.
+    
+    :param baseline: Number of days to create the baseline
+    :type baseline: int
+    :param n_clusters: Either the number of clusters is given or a function to maximize
+    :type n_clusters: int | func
+    """
+
+    def __init__(self, day=None, baseline=91, n_clusters=silhouette_score, **kwargs):
+        super(MobilityCluster, self).__init__(day=day, **kwargs)
+        self._baseline = Mobility(day=self.dates[0], window=baseline)
+        self._n_clusters = n_clusters
+
+    @property
+    def baseline(self):
+        """Baseline used to compute the percentage"""
+
+        return self._baseline
+
+    def overall(self, level=None, pandas=False):
+        output = super(MobilityCluster, self).overall(level=level)
+        _ = self.baseline.overall(level=level)
+        transform = self.baseline.cluster_percentage(_, n_clusters=self._n_clusters)
+        output = self.transform(output, transform)
+        if pandas:
+            import pandas as pd
+            return pd.DataFrame(output, index=self.dates)
+        return output
+
+    def inside_mobility(self, level=None, pandas=False):
+        output = super(MobilityCluster, self).inside_mobility(level=level)
+        _ = self.baseline.inside_mobility(level=level)
+        transform = self.baseline.cluster_percentage(_, n_clusters=self._n_clusters)
+        output = self.transform(output, transform)
+        if pandas:
+            import pandas as pd
+            return pd.DataFrame(output, index=self.dates)
+        return output
+
+
 Travel = Mobility
 
 class BoundingBox(object):
