@@ -285,7 +285,7 @@ def test_states():
 
 
 def test_mobility_day_wclass():
-    from text_models.place import Mobility
+    from text_models import Mobility
 
     class D(object):
         def __init__(self, year, month, day):
@@ -294,10 +294,62 @@ def test_mobility_day_wclass():
             self.day = day
 
     day = D(2020, 7, 19)
-    end = D(2020, 7, 18)
+    end = dict(year=2020, month=7, day=18)
     mob = Mobility(day, window=1, end=end)
     print(mob.dates[-1])
     assert mob.dates[-1].year == 2020
     assert mob.dates[-1].month == 7
     assert mob.dates[-1].day == 19
     assert mob.dates[0].day == 18
+
+
+def test_mobility_overall_pandas():
+    from text_models import Mobility
+    mob = Mobility(window=2)
+    res = mob.overall(pandas=True)
+    assert hasattr(res, "head")
+
+
+def test_mobility_inside_mobilit_pandas():
+    from text_models import Mobility
+    mob = Mobility(window=2)
+    res = mob.inside_mobility(pandas=True)
+    assert hasattr(res, "head")
+
+
+def test_mobilityWeekday():
+    from text_models import MobilityWeekday, Mobility
+    import pandas as pd
+    mob = MobilityWeekday(dict(year=2020, month=7, day=19), window=3,
+                          baseline=10)
+    d = mob.overall()
+    assert isinstance(mob.baseline, Mobility)
+    assert isinstance(d, dict)
+    base = mob.baseline.overall()
+    for a, b in zip(d, base["MX"]):
+        assert  a != b
+    d1 = mob.overall(pandas=True)
+    assert isinstance(d1, pd.DataFrame)
+    d = mob.inside_mobility()
+    assert isinstance(d, dict)
+    d = mob.inside_mobility(pandas=True)
+    assert isinstance(d, pd.DataFrame)
+
+
+def test_mobilityCluster():
+    from text_models import MobilityCluster, Mobility
+    import pandas as pd
+    mob = MobilityCluster(dict(year=2020, month=7, day=19), window=3,
+                          baseline=10)
+    d = mob.overall()
+    assert isinstance(mob.baseline, Mobility)
+    assert isinstance(d, dict)
+    base = mob.baseline.overall()
+    for a, b in zip(d, base["MX"]):
+        assert  a != b
+    d1 = mob.overall(pandas=True)
+    assert isinstance(d1, pd.DataFrame)
+    d = mob.inside_mobility()
+    assert isinstance(d, dict)
+    d = mob.inside_mobility(pandas=True)
+    assert isinstance(d, pd.DataFrame)    
\ No newline at end of file
